import { useTabNavigation } from "./TabNavigation";

export function openElement({
  elementToOpen, 
  classToHide,  /* tabcontent */
  elementToClose,   
  buttonClass, /* = "tablinks" */ 
  eventTargetClass = "active",  /* Hier handleTabChange als Parameter einfügen */
}: {
  elementToOpen: string,
  classToHide: string, 
  classToClose?: string, 
  elementToClose?: string, 
  buttonClass?: string, 
  eventTargetClass?: string,
   /* Neuer Parameter für die Tab-Änderungslogik */
}) {
  const openElement = (event: React.MouseEvent<HTMLElement, MouseEvent>) => {
    let i, elementsToHide, elementsToClose, tabLinks;

    // Hide all elements with the classToHide (e.g., "tabcontent")
    elementsToHide = document.getElementsByClassName(classToHide);
    for (i = 0; i < elementsToHide.length; i++) {
      (elementsToHide[i] as HTMLElement).style.display = "none";
    }

    // If elementToClose is provided, hide these elements too (optional)
    if (elementToClose) {
      elementsToClose = document.getElementsByClassName(elementToClose);
      for (i = 0; i < elementsToClose.length; i++) {
        (elementsToClose[i] as HTMLElement).style.display = "none";
      }
    }

    // Clear the "active" class from elements with the buttonClass (e.g., "tablinks")
    if (buttonClass) {
      tabLinks = document.getElementsByClassName(buttonClass);
      for (i = 0; i < tabLinks.length; i++) {
        tabLinks[i].className = tabLinks[i].className.replace(` ${eventTargetClass}`, "");
      }
    }

    // Display the element to open (elementToOpen, e.g., a city tab or content section)
    const element = document.getElementById(elementToOpen);
    if (element) {
      element.style.display = "block";
    }

    // Add the "active" class to the clicked element
    event.currentTarget.className += ` ${eventTargetClass}`;
    const { handleTabChange } = useTabNavigation(); 
    // Rufe handleTabChange auf, um die URL entsprechend anzupassen
    handleTabChange(elementToOpen);  // Hier wird die Tab-Änderung und URL-Update durchgeführt
  };

  return openElement;
}
